@@ -93,8 +93,7 @@ public:
 public:
 	//bool sortTargets (const Target * f, const Target * g);
 
-	bool openDB(QString pass);
-	bool deleteDB();
+	bool openDB(const QString & pass);
 	bool hasPassword ();
 	bool isReady ();
 	void lock ();
@@ -121,28 +120,41 @@ public:
 	QImage * getPicture (Target * t);
 	QImage * getPictureBack (Target * t);
 
-	bool backupDB();
+	bool backupDB(const QString & prefix);
+	bool restoreDB(const QString & prefix);
+	QString changePassword (const QString & newPassword);
+
+	bool renameGroup (const QString & from, const QString & to);
+	bool deleteGroup (const QString & from);
 
 private:
-	bool openDB();
+	bool deleteDB(const QString & prefix);
+	bool _openDB(const QString & name, const QString & cName = "");
 	bool initDB();
 	bool isInit();
 
-	bool checkPassword (QString a);
-	bool createPassword (QString a);
+	bool migrationFrom (DatabaseManager * mgr);
+
+	bool checkPassword (QString a, int v);
+	bool createPassword (QString a, int v);
+
+	int getVersion ();
+	bool addVersion (int v);
 
 	bool createTargetTable();
 	bool createIdTable();
 	bool createTargetFieldTable();
 
 	bool createTableVersion ();
-	bool migrateVersion (int fromV, int toV);
+	bool migrateVersion (int fromV, int toV, const QString & pas);
 
 	void encrypt (const QString a, QByteArray& b);
 	void decrypt (const QByteArray& a, QString& b);
 
 	void encrypt (const QByteArray& a, QByteArray& b);
 	void decrypt (const QByteArray& a, QByteArray& b);
+	void encryptSHA1 (const QString & a, QByteArray& b);
+
 	QByteArray selectSecretPhrase();
 	bool hasSecretPhrase();
 	bool updateSecretPhrase(QByteArray a);
@@ -156,6 +168,9 @@ private:
 	
 	bool opendb;
 	bool initdb;
+
+	int currentVersion;
+	QString connectionName;
 };
 
 #endif /* DATABASEMANAGER_H_ */
