@@ -50,7 +50,7 @@ RenameGroupDialog::RenameGroupDialog(QWidget *paTarget) : QDialog(paTarget)
 	QDialogButtonBox* dlgBtnBox = new QDialogButtonBox(this);
 	dlgBtnBox->setOrientation(Qt::Vertical);
 
-	QPushButton * closeButton = new QPushButton("Save && Close", this);
+	QPushButton * closeButton = new QPushButton(tr("Save && Close"), this);
 	//closeButton->setFixedHeight(70);
 	closeButton->setContextMenuPolicy(Qt::NoContextMenu);
 	closeButton->setFocusPolicy(Qt::NoFocus);
@@ -63,7 +63,7 @@ RenameGroupDialog::RenameGroupDialog(QWidget *paTarget) : QDialog(paTarget)
 	componentLayout->setSpacing(5);
 
 	// Name label
-	QLabel * nameLabel = new QLabel("Name", this);
+	QLabel * nameLabel = new QLabel(tr("Name"), this);
 	nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
 	//nameLabel->setAlignment(Qt::AlignTop);
 	componentLayout->addWidget(nameLabel, 1, 1, 1, 2);
@@ -216,10 +216,10 @@ void eWallet::showList () {
 
 	createMenu ();
 
-	qDebug () << "setCentralWidget(centralWidget);";
+	//qDebug () << "setCentralWidget(centralWidget);";
 	setCentralWidget(centralWidget);
 
-	qDebug () << "setFocus()";
+	//qDebug () << "setFocus()";
 	centralWidget->setFocus ();
 }
 
@@ -407,7 +407,7 @@ void eWallet::lockWallet () {
 void eWallet::deleteDB () {
 	if (messageBox.isNull()) {
 		messageBox = new QMessageBox(this);
-		int b = messageBox->information(this, "Wallet", "Are you sure you want to remove all your data? You will lost all your data", QMessageBox::Yes, QMessageBox::No);
+		int b = messageBox->information(this, "Wallet", tr("Are you sure you want to remove all your data? You will lost all your data"), QMessageBox::Yes, QMessageBox::No);
 		if (b == QMessageBox::Yes) {
 			::dbManager->reset ();
 
@@ -432,7 +432,7 @@ bool eWallet::openDataBase (const QString & pas)
 			if (!::dbManager->isReady ()) {
 				if (messageBox.isNull()) {
 					messageBox = new QMessageBox(this);
-					messageBox->information(this, "Wallet", "Wrong password", QMessageBox::Ok);
+					messageBox->information(this, "Wallet", tr("Wrong password"), QMessageBox::Ok);
 				}
 				delete messageBox;
 				messageBox = 0;
@@ -440,8 +440,6 @@ bool eWallet::openDataBase (const QString & pas)
 		}
 	}
 	else {
-		showList ();
-
 		if (isShowGroups == 0) {
 			grouplist.clear ();
 			grouplist = ::dbManager->getGroups ();
@@ -452,6 +450,7 @@ bool eWallet::openDataBase (const QString & pas)
 				isShowGroups = 2;
 		}
 
+		showList ();
 		showInfo (true);
 	}
 	return res;
@@ -461,6 +460,7 @@ eWallet::~eWallet ()
 {
 	//delete ::dbManager;
 }
+
 /*
  * TYPES
  * 	S -> String
@@ -635,7 +635,7 @@ void eWallet::showGroups(bool reset)
 	//fnListWidget->setIconSize (QSize (SMALL_WIDTH, SMALL_HEIGH));
 	//fnListWidget->setContentsMargins(10, 1, 0, 1);
 
-	QListWidgetItem* listitem = new QListWidgetItem("<All>", fnListWidget);
+	QListWidgetItem* listitem = new QListWidgetItem(tr("<All>"), fnListWidget);
 	//listitem->set(target->getSummary());
 	fnListWidget->addItem(listitem);
 
@@ -715,24 +715,22 @@ void eWallet::createMenu()
 
 	menuBar()->clear();
 	if (isAskPassword) {
-		menuBar()->addAction("About", this, SLOT(about()));
+		menuBar()->addAction(tr("About"), this, SLOT(about()));
 		if (!isChangingPassword) {
-			menuBar()->addAction("Delete DB", this, SLOT(deleteDB()));
+			menuBar()->addAction(tr("Delete DB"), this, SLOT(deleteDB()));
 		}
-		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
+		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
 	else {
-		menuBar()->addAction("New", this, SLOT(newTarget()));
+		menuBar()->addAction(tr("New"), this, SLOT(newTarget()));
 		if (isShowGroups == 2)
-			menuBar()->addAction("Edit", this, SLOT(_editcTarget()));
-		menuBar()->addAction("Invert Sort", this, SLOT(sort()));
-		menuBar()->addAction("Import", this, SLOT(import()));
-		menuBar()->addAction("Export", this, SLOT(exportData()));
-		//menuBar()->addAction("Change View", this, SLOT(changeMode()));
-
-		menuBar()->addAction("Change Password", this, SLOT(changePassword()));
-
-		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
+			menuBar()->addAction(tr("Edit"), this, SLOT(_editcTarget()));
+		menuBar()->addAction(tr("Invert Sort"), this, SLOT(sort()));
+		menuBar()->addAction(tr("Import"), this, SLOT(import()));
+		menuBar()->addAction(tr("Export"), this, SLOT(exportData()));
+		//menuBar()->addAction(tr("Change View"), this, SLOT(changeMode()));
+		menuBar()->addAction(tr("Change Password"), this, SLOT(changePassword()));
+		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
 }
 
@@ -791,7 +789,7 @@ bool eWallet::_deleteTarget(Target* target)
 {
 	if (messageBox.isNull()) {
 		messageBox = new QMessageBox(this);
-		int b = messageBox->information(this, "Wallet", "Are you sure you want to remove it?", QMessageBox::Yes, QMessageBox::No);
+		int b = messageBox->information(this, "Wallet", tr("Are you sure you want to remove it?"), QMessageBox::Yes, QMessageBox::No);
 		if (b != QMessageBox::Yes) {
 			delete messageBox;
 			messageBox = 0;
@@ -937,9 +935,9 @@ void eWallet::import() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
 	QString s = QFileDialog::getOpenFileName(
 	                this,
-	                "Choose import file",
+	                tr("Choose import file"),
 	                path,
-	                "Text files (*.txt);;");
+	                tr("Text files (*.txt);;"));
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
@@ -1161,9 +1159,9 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 	if (isShowGroups == 1) {
 		if (fnListWidget->currentRow() > 0) {
 			QMenu menu(this);
-			//menu.addAction("View", this, SLOT(_viewcTarget()));
-			menu.addAction("Rename", this, SLOT(renameGroup()));
-			menu.addAction("Delete", this, SLOT(deleteGroup()));
+			//menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
+			menu.addAction(tr("Rename"), this, SLOT(renameGroup()));
+			menu.addAction(tr("Delete"), this, SLOT(deleteGroup()));
 			menu.exec(event->globalPos());
 		}
 	}
@@ -1172,11 +1170,11 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 			//Target * target = list.at(fnListWidget->currentRow());
 
 			QMenu menu(this);
-			menu.addAction("View", this, SLOT(_viewcTarget()));
-			menu.addAction("Edit", this, SLOT(_editcTarget()));
-			menu.addAction("New like this", this, SLOT(_newLikeTarget()));
-			menu.addAction("Duplicate", this, SLOT(_duplicateTarget()));
-			menu.addAction("Delete", this, SLOT(_deletecTarget()));
+			menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
+			menu.addAction(tr("Edit"), this, SLOT(_editcTarget()));
+			menu.addAction(tr("New like this"), this, SLOT(_newLikeTarget()));
+			menu.addAction(tr("Duplicate"), this, SLOT(_duplicateTarget()));
+			menu.addAction(tr("Delete"), this, SLOT(_deletecTarget()));
 			menu.exec(event->globalPos());
 		}
 	}
@@ -1186,9 +1184,9 @@ void eWallet::exportData() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
 	QString s = QFileDialog::getSaveFileName(
 	                this,
-	                "Choose export file",
+	                tr("Choose export file"),
 	                path,
-	                "Text files (*.txt);;");
+	                tr("Text files (*.txt);;"));
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 	if (!s.isNull () && !s.isEmpty ()) {
@@ -1334,6 +1332,7 @@ void eWallet::newTarget() {
 
 void eWallet::_newLikeTarget() {
 	if (fnListWidget->currentRow() >= 0) {
+		if (fnListWidget->isItemHidden(fnListWidget->item(fnListWidget->currentRow()))) return;
 		Target * target = list.at(fnListWidget->currentRow());
 		newLikeTarget (target);
 	}
@@ -1341,6 +1340,7 @@ void eWallet::_newLikeTarget() {
 
 void eWallet::_duplicateTarget() {
 	if (fnListWidget->currentRow() >= 0) {
+		if (fnListWidget->isItemHidden(fnListWidget->item(fnListWidget->currentRow()))) return;
 		Target * target = list.at(fnListWidget->currentRow());
 		duplicateTarget (target);
 	}
@@ -1348,18 +1348,21 @@ void eWallet::_duplicateTarget() {
 
 void eWallet::_editcTarget() {
 	if (fnListWidget->currentRow() >= 0) {
+		if (fnListWidget->isItemHidden(fnListWidget->item(fnListWidget->currentRow()))) return;
 		Target * target = list.at(fnListWidget->currentRow());
 		editTarget(target);
 	}
 }
 void eWallet::_deletecTarget() {
 	if (fnListWidget->currentRow() >= 0) {
+		if (fnListWidget->isItemHidden(fnListWidget->item(fnListWidget->currentRow()))) return;
 		Target * target = list.at(fnListWidget->currentRow());
 		deleteTarget(target);
 	}
 }
 void eWallet::_viewcTarget() {
 	if (fnListWidget->currentRow() >= 0) {
+		if (fnListWidget->isItemHidden(fnListWidget->item(fnListWidget->currentRow()))) return;
 		Target * target = list.at(fnListWidget->currentRow());
 		viewTarget(target);
 	}
@@ -1385,7 +1388,7 @@ void eWallet::askPassword () {
 }
 
 void eWallet::about() {
-	QMessageBox::about(this, "About Wallet", TEXT_ABOUT);
+	QMessageBox::about(this, tr("About Wallet"), TEXT_ABOUT);
 }
 
 bool eWallet::finalPassword (const QString & pass) {
@@ -1420,18 +1423,15 @@ void eWallet::reallyChangePassword (const QString & newPassword) {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
 	QMessageBox * messageBox = new QMessageBox (this);
-	messageBox->information(this, "Wallet", "Changing password, please wait until application quits", QMessageBox::Ok);
+	messageBox->information(this, "Wallet", tr("Changing password, please wait until application quits"), QMessageBox::Ok);
 
 	QString p = ::dbManager->changePassword(newPassword);
 
 	//QMessageBox * messageBox = new QMessageBox (this);
 	if (p.length() == 0)
-		messageBox->information(this, "Wallet", "Password changed successfully, application will exit", QMessageBox::Ok);
+		messageBox->information(this, "Wallet", tr("Password changed successfully, application will exit"), QMessageBox::Ok);
 	else {
-		QString message ("Password CANNOT BE changed, because ");
-		message.append (p);
-		message.append ("application will exit");
-		messageBox->information(this, "Wallet", message , QMessageBox::Ok);
+		messageBox->information(this, "Wallet", tr("Password CANNOT BE changed, because %1, and application will exit").arg(p) , QMessageBox::Ok);
 	}
 
 	delete messageBox;
